searchData={"content_type":"text/markdown","items":[{"doc":"Swiss knife module for opentelemetry instrumentation.\nIt can be used to setup instrumentation with:\n- Teleplug\n- Telepoison\n- OpentelemetryAbsinthe\n- OpentelemetryEcto\n(the libraries need to be installed separately)","ref":"PrimaOpentelemetryEx.html","title":"PrimaOpentelemetryEx","type":"module"},{"doc":"","ref":"PrimaOpentelemetryEx.html#set_resource/0","title":"PrimaOpentelemetryEx.set_resource/0","type":"function"},{"doc":"Setup all the opentelemetry instrumentation.\nYou are supposed to call it in your application start function.","ref":"PrimaOpentelemetryEx.html#setup/0","title":"PrimaOpentelemetryEx.setup/0","type":"function"},{"doc":"Wrapper of Task that mantains the span context","ref":"PrimaOpentelemetryEx.TeleTask.html","title":"PrimaOpentelemetryEx.TeleTask","type":"module"},{"doc":"","ref":"PrimaOpentelemetryEx.TeleTask.html#async/1","title":"PrimaOpentelemetryEx.TeleTask.async/1","type":"function"},{"doc":"","ref":"PrimaOpentelemetryEx.TeleTask.html#await/1","title":"PrimaOpentelemetryEx.TeleTask.await/1","type":"function"},{"doc":"","ref":"PrimaOpentelemetryEx.TeleTask.html#start/1","title":"PrimaOpentelemetryEx.TeleTask.start/1","type":"function"},{"doc":"# The MIT License (MIT)\n\nCopyright (c) 2020 Prima.it\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# PrimaOpentelemetryEx\n\n[![Module Version](https://img.shields.io/hexpm/v/prima_opentelemetry_ex.svg)](https://hex.pm/packages/prima_opentelemetry_ex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/prima_opentelemetry_ex/)\n[![Total Download](https://img.shields.io/hexpm/dt/prima_opentelemetry_ex.svg)](https://hex.pm/packages/prima_opentelemetry_ex)\n[![License](https://img.shields.io/hexpm/l/prima_opentelemetry_ex.svg)](https://github.com/primait/prima_opentelemetry_ex/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/primait/prima_opentelemetry_ex.svg)](https://github.com/primait/prima_opentelemetry_ex/commits/master)\n\nThis is your one-stop source of all things opentelemetry in elixir.\nAdd\n\n```elixir\n    {:prima_opentelemetry_ex, \"~> 2.0\"}\n```\n\nand the respective telemetry libraries to your dependencies and you are good to go.\n\nWhat's covered:\n\n- HTTPoison (via [Telepoison](https://github.com/primait/telepoison)) - to trace the http calls you make to external system and to pass along the trace context\n- Plug - to link your phoenix/plug handled requests with their http clients traces\n  * you will need to add teleplug to your pipeline\n- Absinthe - to trace your GraphQL resolutions in a single span\n  * you need to install `opentelemetry_absinthe`\n- Ecto - to trace your database transactions in a single span\n  * you also need to install `opentelemetry_ecto`","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"To start collecting traces just put\n\n``` elixir\nPrimaOpentelemetryEx.setup()\n```\n\nin your application start function.\n\nTo trace your outgoing http calls you need to use the `Telepoison` module as a drop-in replacement for `HTTPoison`.\ne.g.\n\n``` elixir\nTelepoison.post(\"https://example.com/\", \"{'example': 1}\", %{\"content-type\" => \"application/json\"}, [timeout: 5_000])\n```\n\nFor more informations see telepoison [usage](https://github.com/primait/telepoison#usage)\n\nTo emit server spans (from plug) you need to add `Teleplug` to your plug pipeline either in your phoenix endpoint module or in every pipeline you want to trace (contained in your router module if you are using phoenix).\ne.g.\n\n``` elixir\npipeline :example do\n    plug Teleplug\n    plug Plug.Logger\nend\n```\n\nGraphQL and database spans are emitted automatically as long as the relevant telemetry libraries are installed.\n\nTo keep traces across elixir tasks you need to use `PrimaOpentelemetryEx.TeleTask` module that wraps `start/1`, `async/1` and `await/1`.\n\nTo see emitted traces on your local dev machine, you can use the [jaeger all-in-one image](https://hub.docker.com/r/jaegertracing/all-in-one/).  \nTo add it to your local Docker Compose setup, simply add a service (which your web container should depend on):\n\n``` yaml\n  jaeger:\n    image: jaegertracing/all-in-one:1.35\n    ports:\n      - 16686:16686\n    environment:\n      COLLECTOR_OTLP_ENABLED: true\n      COLLECTOR_OTLP_HTTP_HOST_PORT: 55681\n```\n\nYou can then use the [jaeger UI](http://localhost:16686/search) to search for your traces.\n\nBe advised that `prima_opentelemetry_ex` uses ENV vars to set service name and version inside the exported traces. Those values are important, for example, to make datadog correctly recognize services and their relative deployments (through version tracking); the two ENV var currently used are:\n\n- `APP_NAME` for service name\n- `VERSION` for service version\n\nThese are supposed to be correctly set up inside prima containers in production; if you want to you can set them up for local development through docker-compose, for example:\n\n``` yaml\nservices:\n  web:\n    build: .\n    volumes:\n      - \"~/.ssh:/home/app/.ssh\"\n      - \"~/.aws:/home/app/.aws\"\n      - \"~/.gitconfig:/home/app/.gitconfig\"\n      - .:$PWD\n    ports:\n      - 230:4000\n    depends_on:\n      - jaeger\n    working_dir: $PWD\n    environment:\n      APP_NAME: MY_SERVICE_NAME\n      VERSION: 0.0.0-dev\n    env_file:\n      - biscuit.env\n```","ref":"readme.html#usage","title":"Usage - Overview","type":"extras"},{"doc":"","ref":"readme.html#configuration","title":"Configuration - Overview","type":"extras"},{"doc":"If you want to disable tracing via configuration (if you need to turn it off for a particular environment, for example) like so:\n\n``` elixir\nconfig :prima_opentelemetry_ex, :enabled, false\n```\n\nYou can also disable the instrumentation for Ecto and/or Absinthe by setting the `exclude` key like in the following example:\n\n```elixir\nconfig :prima_opentelemetry_ex, exclude: [:ecto, :absinthe]\n```\n\nTo configure the endpoint to send traces to, you can use the `:endpoint` configuration key to set protocol, host and port of the destination endpoint (agent or collector).\nIn this example you can see the default value for every configuration:\n\n``` elixir\nconfig :prima_opentelemetry_ex, :endpoint,\n    protocol: :http,\n    host: \"jaeger\",\n    port: 55681\n```\n\nThese values get used to build the configuration for the opentelemetry_exporter (through a batch processor). If you want to have a bit more freedom and set opentelemetry configuration by yourself feel free to do so, it won't get overwritten.\nExample opentelemetry configuration:\n\n``` elixir\nconfig :opentelemetry, :processors,\n  otel_batch_processor: %{\n    exporter: {:opentelemetry_exporter, %{endpoints: [{:http, \"jaeger\", 55681, []}]}}\n  }\n```","ref":"readme.html#general","title":"General - Overview","type":"extras"},{"doc":"You can change the default span name and choose which informations about your graphql you want traced; e.g.\n\n``` elixir\nconfig :prima_opentelemetry_ex, :graphql,\n    span_name: \"graphql resolution\",\n    trace_request_variables: false\n```\n\nAll the `:graphql` configurations get passed directly to `OpentelemetryAbsinthe`. For more informations about what you can do with them, see opentelemetry_absinthe [readme](https://github.com/primait/opentelemetry_absinthe#readme)","ref":"readme.html#graphql","title":"GraphQL - Overview","type":"extras"},{"doc":"Copyright (c) 2020 Prima.it\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license","title":"Copyright and License - Overview","type":"extras"}],"producer":{"name":"ex_doc","version":"0.35.1"},"proglang":"elixir"}